@@ -1,8 +1,8 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "ob-dall-e-shell" "1.20.1"
+(define-package "ob-dall-e-shell" "20241112.2008"
   "Org babel functions for DALL-E evaluation."
   '((emacs        "27.1")
-    (dall-e-shell "0.42.1"))
+    (dall-e-shell "0.43.1"))
   :url "https://github.com/xenodium/chatgpt-shell"
-  :commit "a24c003c79a720eafffc79bc3885070735f667f6"
-  :revdesc "a24c003c79a7")
+  :commit "1ef7951bf47f63d2d0808c3f475f82eac8c9b219"
+  :revdesc "1ef7951bf47f")
